==> ts-util-v1_0_0-env.tar.gz: ts-util-v1_0_0-env/src/ts/util/text/StringConvertException.java <==
/*
 * StringConvertException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util.text;

/**
 * ̕ύXȂꍇɃX[ONXB
 *
 * @author  V. 
 * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:05 $
 */
public class StringConvertException extends Exception
{
  /* VAԍB */
  static final long serialVersionUID = 1584378524238190509L;

  /** ύXfꂽCfbNXB */
  private int stoppedIndex_ = 0;

  /** f܂ŕύXꂽB */
  private String convertedString_ = "";

  /**
   * ύXfꂽCfbNXƁAf܂ŕϊꂽ
   * ƂRXgN^B
   *
   * @param  stoppedIndex  ύXfꂽCfbNXB
   * @param  convertedString  f܂ŕϊꂽB
   */
  public StringConvertException(int stoppedIndex, String convertedString)
  {
    stoppedIndex_ = stoppedIndex;
    convertedString_ = convertedString;
  }

  /**
   * ύXfꂽCfbNXƁAf܂ŕϊꂽƁA
   * ObZ[WɂƂRXgN^B
   *
   * @param  stoppedIndex  ύXfꂽCfbNXB
   * @param  convertedString  f܂ŕϊꂽB
   * @param  msg ObZ[WB
   */
  public StringConvertException(
    int stoppedIndex, String convertedString, String msg)
  {
    super(msg);

    stoppedIndex_ = stoppedIndex;
    convertedString_ = convertedString;
  }

  /**
   * ύXfꂽCfbNX擾B
   *
   * @return ύXfꂽCfbNXB
   */
  public int getStoppedIndex()
  {
    return stoppedIndex_ ;
  }

  /**
   * f܂ŕϊꂽ擾B
   *
   * @return f܂ŕϊꂽB
   */
  public String convertedString()
  {
    return convertedString_ ;
  }
}

==> ts-util-1.1.0.env.tar.gz: ts-util-1.1.0.env/src/ts/util/text/StringConvertException.java <==
/*
 * StringConvertException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util.text;

/**
 * ̕ύXȂꍇɃX[ONXB
 *
 * @author  V. 
 * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:17 $
 */
public class StringConvertException extends Exception
{
  /* VAԍB */
  static final long serialVersionUID = 1584378524238190509L;

  /** ύXfꂽCfbNXB */
  private int stoppedIndex_ = 0;

  /** f܂ŕύXꂽB */
  private String convertedString_ = "";

  /**
   * ύXfꂽCfbNXƁAf܂ŕϊꂽ
   * ƂRXgN^B
   * <br>
   * ȂAłCfbNXƂ́AR[hE|CgPʂ̒lłB
   *
   * @param  index  ύXfꂽCfbNXB
   * @param  converted  f܂ŕϊꂽB
   */
  public StringConvertException(int index, CharSequence converted)
  {
    stoppedIndex_ = index;
    convertedString_ = (converted == null) ? null : converted.toString();
  }

  /**
   * ύXfꂽCfbNXƁAf܂ŕϊꂽƁA
   * ObZ[WɂƂRXgN^B
   * <br>
   * ȂAłCfbNXƂ́AR[hE|CgPʂ̒lłB
   *
   * @param  index  ύXfꂽCfbNXB
   * @param  converted  f܂ŕϊꂽB
   * @param  msg ObZ[WB
   */
  public StringConvertException(int index, CharSequence converted, String msg)
  {
    super(msg);

    stoppedIndex_ = index;
    convertedString_ = (converted == null) ? null : converted.toString();
  }

  /**
   * ύXfꂽCfbNX擾B
   * <br>
   * ȂAłCfbNXƂ́AR[hE|CgPʂ̒lłB
   *
   * @return ύXfꂽCfbNXB
   */
  public int getStoppedIndex()
  {
    return stoppedIndex_ ;
  }

  /**
   * f܂ŕϊꂽ擾B
   *
   * @return f܂ŕϊꂽB
   */
  public String convertedString()
  {
    return convertedString_ ;
  }
}
